#!/usr/bin/env python
import sys
import glob
import re
import json
import radix
import arrow

r = radix.Radix()
r.add("195.66.224.0/22")

BIN=60*15

### load reliable pairs
'''
prb_id dst_addr infra_hit_rate dst_hit_rate
6527 194.81.236.229 96 1.0 1.0
6674 83.136.33.8 96 0.7604166666666666 0.0
6879 202.165.66.5 96 1.0 1.0
6380 185.134.197.94 96 1.0 1.0
'''

rpairs = set() # reliable pairs

with open("reliability.pairs.test.txt",'rt') as inf:
    for line in inf:
        line = line.rstrip('\n')
        fields = line.split()
        if float( fields[3] ) == 1.0 and float( fields[4] ) == 1.0:
            pair = ( fields[0], fields[1] )
            rpairs.add( pair )


series = {} # keyed by ts_bin
### go through all traces for this pair and figure out what linx IPs where seen at which timestamp

def infra_ips( r, hops ):
    ips = set()
    for h in hops:
        if 'hop_addr' in h:
            if r.search_best( h['hop_addr'] ):
                ips.add( h['hop_addr'] )
    return ips

files = glob.glob("./pairs/*.jsonf")
for fname in files:
    rmo = re.match('./pairs/(\d+)\.(.*)\.jsonf', fname)
    if rmo:
        prb_id = rmo.group(1)
        dst_addr = rmo.group(2)
        if (prb_id,dst_addr) in rpairs:
            #print( prb_id, dst_addr, file=sys.stderr )
            with open(fname,'rt') as inf:
                for line in inf:
                    line = line.rstrip('\n')
                    if line == "":
                        continue
                    d = json.loads( line )
                    ts = arrow.get( d['start_time'], 'YYYY-MM-DD HH:mm:ss ZZZ').timestamp

                    ts_bin = ts - ts % BIN 
                    series.setdefault( ts_bin, set() )
                    ips = infra_ips( r, d['hops'] )
                    #if len(ips) > 0:
                    #    print( ips, file=sys.stderr )
                    for ip in ips:
                        series[ ts_bin ].add( ip )

min_ts = min( series.keys() ) 
max_ts = max( series.keys() )

this_ts = min_ts
while this_ts <= max_ts:
    ips = []
    if this_ts in series:
        ips = sorted( list( series[ this_ts ] ) )
    print(this_ts, len( ips ), "|".join(ips) )
    this_ts += BIN
